uri!() { /* proc-macro */ }Expand description
Build an URI with a 'static lifetime at compile time.
This macro expects a single string literal token representing the URI.
uri!() { /* proc-macro */ }Build an URI with a 'static lifetime at compile time.
This macro expects a single string literal token representing the URI.